# IO.Swagger - the C# library for the DiscoverSnoop

API for DiscoverSnoop Service

This C# SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.9.250210
- SDK version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.dotnet.CSharpClientCodegen

<a name="frameworks-supported"></a>
## Frameworks supported
- .NET 4.7.1 or later

<a name="dependencies"></a>
## Dependencies
- [RestSharp](https://www.nuget.org/packages/RestSharp) - 111.4.1 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 7.0.0 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.2.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742)

<a name="installation"></a>
## Installation

Run the following commands to generate the DLL
```
cd src/IO.Swagger
dotnet restore
dotnet build
```

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;
```

<a name="packaging"></a>
## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out IO.Swagger.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.


<a name="getting-started"></a>
## Getting Started

```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class Example
    {
        public void main()
        {

            var apiInstance = new AlertsApi();
            var id = id_example;  // string | ID of the alert to edit ; if adding a new one leave blank
            var alertname = alertname_example;  // string | Name of the alert
            var activated = true;  // bool? | Should the alert be activated or not
            var type = 56;  // int? | Alert type (1= New content for website, 2=New performing contents), 3=New contents in category
            var channel = 56;  // int? | 1 for email, 2 for Slack, 3 for Google Chat, 4 for JSON
            var recipient = recipient_example;  // string | Email address of recipient or webhook for Slack/Gchat or JSON endpoint
            var param1 = param1_example;  // string | Parameter 1 (meaning changes with alert type) (optional) 
            var param2 = param2_example;  // string | Parameter 2 (meaning changes with alert type) (optional) 
            var param3 = param3_example;  // string | Parameter 3 (meaning changes with alert type) (optional) 
            var param4 = param4_example;  // string | Parameter 4 (meaning changes with alert type) (optional) 
            var param5 = param5_example;  // string | Parameter 5 (meaning changes with alert type) (optional) 
            var param6 = param6_example;  // string | Parameter 6 (meaning changes with alert type) (optional) 

            try
            {
                // Edit or insert new alert
                List<Domains> result = apiInstance.AlertsChangeGet(id, alertname, activated, type, channel, recipient, param1, param2, param3, param4, param5, param6);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling AlertsApi.AlertsChangeGet: " + e.Message );
            }
        }
    }
}
```

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://api.discoversnoop.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AlertsApi* | [**AlertsChangeGet**](docs/AlertsApi.md#alertschangeget) | **GET** /alerts_change | Edit or insert new alert
*AlertsApi* | [**AlertsDeleteGet**](docs/AlertsApi.md#alertsdeleteget) | **GET** /alerts_delete | Permanently delete the alert
*AlertsApi* | [**AlertsGet**](docs/AlertsApi.md#alertsget) | **GET** /alerts | Get alerts for user account
*FavsApi* | [**FavsAddGet**](docs/FavsApi.md#favsaddget) | **GET** /favs_add | Create a new fav
*FavsApi* | [**FavsDeleteGet**](docs/FavsApi.md#favsdeleteget) | **GET** /favs_delete | Permanently delete the fav
*FavsApi* | [**FavsGet**](docs/FavsApi.md#favsget) | **GET** /favs | Get favorites
*FavsApi* | [**FavsUpdateGet**](docs/FavsApi.md#favsupdateget) | **GET** /favs_update | Update the fav
*HistoricalApi* | [**CategoriesGet**](docs/HistoricalApi.md#categoriesget) | **GET** /categories | Get historical stats for categories
*HistoricalApi* | [**CategoryGet**](docs/HistoricalApi.md#categoryget) | **GET** /category | Get history for category ID
*HistoricalApi* | [**DomainGet**](docs/HistoricalApi.md#domainget) | **GET** /domain | Get history for domain name
*HistoricalApi* | [**DomainsGet**](docs/HistoricalApi.md#domainsget) | **GET** /domains | Get historical stats for domains
*HistoricalApi* | [**EntitiesGet**](docs/HistoricalApi.md#entitiesget) | **GET** /entities | Get historical stats for entities
*HistoricalApi* | [**EntityGet**](docs/HistoricalApi.md#entityget) | **GET** /entity | Get history for entity
*HistoricalApi* | [**PageGet**](docs/HistoricalApi.md#pageget) | **GET** /page | Get page history for URL
*HistoricalApi* | [**PagesGet**](docs/HistoricalApi.md#pagesget) | **GET** /pages | Get historical stats for pages
*InfoApi* | [**CategoriesListGet**](docs/InfoApi.md#categorieslistget) | **GET** /categories_list | Get list of categories used in the product
*InfoApi* | [**CountriesListGet**](docs/InfoApi.md#countrieslistget) | **GET** /countries_list | Get list of countries available in the product
*KbApi* | [**KbArticlesGet**](docs/KbApi.md#kbarticlesget) | **GET** /kb_articles | Get knowledge base articles
*LiveApi* | [**LivecategoriesGet**](docs/LiveApi.md#livecategoriesget) | **GET** /livecategories | Get livedata stats for categories
*LiveApi* | [**LivedomainsGet**](docs/LiveApi.md#livedomainsget) | **GET** /livedomains | Get livedata stats for domains
*LiveApi* | [**LiveentitiesGet**](docs/LiveApi.md#liveentitiesget) | **GET** /liveentities | Get livedata stats for entities
*LiveApi* | [**LivepagesGet**](docs/LiveApi.md#livepagesget) | **GET** /livepages | Get livedata stats for pages
*UserApi* | [**UserCountriesChangeGet**](docs/UserApi.md#usercountrieschangeget) | **GET** /user_countries_change | Change user's activated countries
*UserApi* | [**UserCustidChangeGet**](docs/UserApi.md#usercustidchangeget) | **GET** /user_custid_change | Change user customer id. This function is system reserved
*UserApi* | [**UserDeleteGet**](docs/UserApi.md#userdeleteget) | **GET** /user_delete | Permanently delete the user
*UserApi* | [**UserDetailsChangeGet**](docs/UserApi.md#userdetailschangeget) | **GET** /user_details_change | Change user details
*UserApi* | [**UserLoginGet**](docs/UserApi.md#userloginget) | **GET** /user_login | Login user with his credentials
*UserApi* | [**UserMessagesGet**](docs/UserApi.md#usermessagesget) | **GET** /user_messages | Get messages for user
*UserApi* | [**UserPasswordChangeGet**](docs/UserApi.md#userpasswordchangeget) | **GET** /user_password_change | Change user password
*UserApi* | [**UserPasswordResetGet**](docs/UserApi.md#userpasswordresetget) | **GET** /user_password_reset | Reset user password
*UserApi* | [**UserRefreshSubscriptionGet**](docs/UserApi.md#userrefreshsubscriptionget) | **GET** /user_refresh_subscription | Refresh user rights with his Customer ID. This function is system reserved
*UserApi* | [**UserRegisterGet**](docs/UserApi.md#userregisterget) | **GET** /user_register | Login user with his credentials

<a name="documentation-for-models"></a>
## Documentation for Models

 - [Model.AlertCollection](docs/AlertCollection.md)
 - [Model.Alerts](docs/Alerts.md)
 - [Model.Categories](docs/Categories.md)
 - [Model.CategoriesCollection](docs/CategoriesCollection.md)
 - [Model.CategoriesList](docs/CategoriesList.md)
 - [Model.CategoriesListCollection](docs/CategoriesListCollection.md)
 - [Model.Category](docs/Category.md)
 - [Model.CountriesList](docs/CountriesList.md)
 - [Model.CountriesListCollection](docs/CountriesListCollection.md)
 - [Model.DistributionCollection](docs/DistributionCollection.md)
 - [Model.Domain](docs/Domain.md)
 - [Model.Domains](docs/Domains.md)
 - [Model.DomainsCollection](docs/DomainsCollection.md)
 - [Model.Entities](docs/Entities.md)
 - [Model.EntitiesCollection](docs/EntitiesCollection.md)
 - [Model.Entity](docs/Entity.md)
 - [Model.Favs](docs/Favs.md)
 - [Model.FavsCollection](docs/FavsCollection.md)
 - [Model.KB](docs/KB.md)
 - [Model.KBCollection](docs/KBCollection.md)
 - [Model.Message](docs/Message.md)
 - [Model.MessageCollection](docs/MessageCollection.md)
 - [Model.MetricsCollection](docs/MetricsCollection.md)
 - [Model.Page](docs/Page.md)
 - [Model.Pages](docs/Pages.md)
 - [Model.PagesCollection](docs/PagesCollection.md)
 - [Model.TransactionInfo](docs/TransactionInfo.md)
 - [Model.UserCollection](docs/UserCollection.md)
 - [Model.UserInfo](docs/UserInfo.md)

<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="bearerAuth"></a>
### bearerAuth


